@@ -25,14 +25,10 @@ def tests_dir(request: pytest.Session):
     yield TESTS_DIR
 
 
-@pytest.fixture(scope="session", autouse=True)
-def tests_dir(request: pytest.Session) -> pathlib.Path:
-    """
-    When the test starts, verify that TESTS_DIR is available in non-fixture functions in this module
-    """
-    path = pathlib.Path(request.config.rootdir) / "tests"
-    pytest_idem.runner.TESTS_DIR = path
-    return path
+@pytest.fixture(scope="module")
+def acct_key():
+    key = pytest_idem.runner.generate_acct_key()
+    yield key
 
 
 @pytest.fixture(scope="session")
